Public APIs
===========

.. automodule:: flask_openheart
    :members:


.. py:class:: flask.Flask

    .. py:method:: route(rule, **options)

    .. py:attribute:: openheart
        :type: flask_openheart.OpenHeartMapper


.. py:class:: flask.Request

    .. py:attribute:: openheart
        :type: flask_openheart.OpenHeartRequest
